==> harmattan-theme_0.1-2.tar.gz: harmattan-theme-0.1/src/usr/share/themes/Harmattan-theme/build_harmattan.py <==
#!/usr/bin/python2.5
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
import py2deb
import os
if __name__ == "__main__":
    try:
        os.chdir(os.path.dirname(sys.argv[0]))
    except:
        pass
    print
    p=py2deb.Py2deb("Harmattan-theme")
    p.description="Harmattan theme in white"
    p.author="robin92"
    p.mail="r.lundgren92@gmail.com"
    p.depends = "theme-customizer"
    p.section="user/desktop"
    p.icon = "/home/user/MyDocs/harmattan/icon.png"
    p.arch="all"                
    p.urgency="low"
    p.distribution="fremantle"
    p.repository="extras-devel"
    p.xsbc_bugtracker="web page for bugtracker, i kept getting a post install error because i did not have a proper bugtracker link"
    p.postinstall="""#! /bin/sh -e
    


optify () {
    f="$1"
    if [ ! -h "/$f" ]; then

        # This is not atomic, but re-startable: if interrupted, doing
        # this again will eventually finish with the correct result.
        #
        # XXX - At least that's the idea, but tar needs to be properly
        #       instructed to overwrite the targets.

        echo >&2 "Optifying $f -> /opt/maemo/$f"
        if [ -d "/$f" ]; then
            (cd "/" && tar cf - "$f") | (cd "/opt/maemo/" && tar xf -)
        fi
        mv "/$f" "/$f.removed"
        ln -s "/opt/maemo/$f" "/$f"
    fi

    if [ -e "/$f.removed" ]; then
        rm -rf "/$f.removed"
    fi
}

"""

    #p.postremove=
    #p.preinstall="""#!/bin/sh
    #p.preremove="""#!/bin/sh

    version = "0.1"           
    build = "1"    
    changeloginformation = "Beta release. not finshed"
    dir_name = "src"
    for root, dirs, files in os.walk(dir_name):
            real_dir = "/" + root[len(dir_name):]
            fake_file = []
            for f in files:
                fake_file.append(root + os.sep + f + "|" + f)
            if len(fake_file) > 0:
                p[real_dir] = fake_file
    print p
    r = p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)

==> harmattan-theme_0.3-0.tar.gz: harmattan-theme-0.3/src/usr/share/themes/Harmattan-theme/build_harmattan.py <==
#!/usr/bin/python2.5
# -*- coding: utf-8 -*-
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published
## by the Free Software Foundation; version 2 only.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
import py2deb
import os
if __name__ == "__main__":
    try:
        os.chdir(os.path.dirname(sys.argv[0]))
    except:
        pass
    print
    p=py2deb.Py2deb("harmattan-theme")
    p.description="Harmattan theme in white"
    p.author="robin92"
    p.mail="r.lundgren92@gmail.com"
    p.depends = "theme-customizer"
    p.section="user/desktop"
    p.icon = "/home/user/MyDocs/harmattan/icon.png"
    p.arch="all"                
    p.urgency="low"
    p.distribution="fremantle"
    p.repository="extras-devel"
    p.xsbc_bugtracker="web page for bugtracker, i kept getting a post install error because i did not have a proper bugtracker link"
    p.postinstall="""#! /bin/sh -e
    


optify () {
    f="$1"
    if [ ! -h "/$f" ]; then

        # This is not atomic, but re-startable: if interrupted, doing
        # this again will eventually finish with the correct result.
        #
        # XXX - At least that's the idea, but tar needs to be properly
        #       instructed to overwrite the targets.

        echo >&2 "Optifying $f -> /opt/maemo/$f"
        if [ -d "/$f" ]; then
            (cd "/" && tar cf - "$f") | (cd "/opt/maemo/" && tar xf -)
        fi
        mv "/$f" "/$f.removed"
        ln -s "/opt/maemo/$f" "/$f"
    fi

    if [ -e "/$f.removed" ]; then
        rm -rf "/$f.removed"
    fi
}

"""

    #p.postremove=
    #p.preinstall="""#!/bin/sh
    #p.preremove="""#!/bin/sh

    version = "0.2"           
    build = "0"    
    changeloginformation = "Changed lockscreen, backgrouns, text colors, background color ans lots of images"
    dir_name = "src"
    for root, dirs, files in os.walk(dir_name):
            real_dir = "/" + root[len(dir_name):]
            fake_file = []
            for f in files:
                fake_file.append(root + os.sep + f + "|" + f)
            if len(fake_file) > 0:
                p[real_dir] = fake_file
    print p
    r = p.generate(version,build,changelog=changeloginformation,tar=True,dsc=True,changes=True,build=False,src=True)
